@@ -1,7 +1,5 @@
 #![no_std]
 
-use core::ops::FnOnce;
-
 /// `TypedBuilder` is not a real type - deriving it will generate a `::builder()` method on your
 /// struct that will return a compile-time checked builder. Set the fields using setters with the
 /// same name as the struct's fields and call `.build()` when you are done to create your object.
@@ -91,6 +89,28 @@ use core::ops::FnOnce;
 ///     decide which type shall be constructed. In both cases an [`Into`] conversion is required to
 ///     be defined from the original type to the target type.
 ///
+/// - The `builder_type(...)` subsection also has:
+///   - `attributes` - for adding attributes to the builder type. Note that the full attribute
+///     syntax is required **inside** this section -
+///     ```ignore
+///     #[builder(builder_type(attributes(
+///         #[derive(...)]
+///         #[some_other_attribute]
+///     )))]
+///     ```
+///
+///     Example:
+///     
+///     ```
+///     use typed_builder::TypedBuilder;
+///
+///     #[derive(TypedBuilder)]
+///     #[builder(builder_type(attributes(#[derive(Debug)])))]
+///     struct Foo {
+///         x: i32,
+///     }
+///     ```
+///
 /// - `field_defaults(...)` is structured like the `#[builder(...)]` attribute you can put on the
 ///   fields and sets default options for fields of the type. If specific field need to revert some
 ///   options to the default defaults they can prepend `!` to the option they need to revert, and
@@ -132,11 +152,27 @@ use core::ops::FnOnce;
 ///
 /// - `default = ...`: make the field optional, defaulting to the expression `...`.
 ///
+/// - `default_where(...)`: add trait bounds to the default. This means that the `default`
+///   expression (or type default) is allowed to rely on these bounds, but the field will not have
+///   a default if these trait bounds are not fulfilled.
+///
+///   Example:
+///
+///    ```
+///    use typed_builder::TypedBuilder;
+///
+///    #[derive(TypedBuilder)]
+///    struct Foo<T> {
+///        #[builder(default, default_where(T: Default))]
+///        bar: T,
+///    }
+///    ```
+///
 /// - `default_code = "..."`: make the field optional, defaulting to the expression `...`. Note that
-///    you need to enclose it in quotes, which allows you to use it together with other custom
-///    derive proc-macro crates that complain about "expected literal".
-///    Note that if `...` contains a string, you can use raw string literals to avoid escaping the
-///    double quotes - e.g. `#[builder(default_code = r#""default text".to_owned()"#)]`.
+///   you need to enclose it in quotes, which allows you to use it together with other custom
+///   derive proc-macro crates that complain about "expected literal". Note that if `...` contains
+///   a string, you can use raw string literals to avoid escaping the double quotes - e.g.
+///   `#[builder(default_code = r#""default text".to_owned()"#)]`.
 ///
 /// - `via_mutators`: initialize the field when constructing the builder, useful in combination
 ///   with [mutators](#mutators).
@@ -196,14 +232,28 @@ use core::ops::FnOnce;
 ///   - `strip_bool`: for `bool` fields only, this makes the setter receive no arguments and simply
 ///     set the field's value to `true`. When used, the `default` is automatically set to `false`.
 ///
-///   - `strip_bool(fallback = field_bool)`: for `bool` fields only. As above this
-///      allows passing the boolean value. The name given to the fallback method adds
-///      another method to the builder without where the bool value can be specified.
+///   - `strip_bool(fallback = field_bool)`: for `bool` fields only. As above this allows passing
+///     the boolean value. The name given to the fallback method adds another method to the builder
+///     without where the bool value can be specified.
 ///
 ///   - `transform = |param1: Type1, param2: Type2 ...| expr`: this makes the setter accept
 ///     `param1: Type1, param2: Type2 ...` instead of the field type itself. The parameters are
 ///     transformed into the field type using the expression `expr`. The transformation is performed
-///     when the setter is called.
+///     when the setter is called. `transform` can also be provided in full `fn` syntax,
+///     to allow custom lifetimes, a generic and a where clause.
+///     Example:
+///     ```rust
+///     #[builder(
+///         setter(
+///             fn transform<'a, M>(value: impl IntoValue<'a, String, M>) -> String
+///             where
+///                 M: 'a,
+///             {
+///                 value.into_value()
+///             },
+///         )
+///     )]
+///     ```
 ///
 ///   - `prefix = "..."` prepends the setter method with the specified prefix. For example, setting
 ///     `prefix = "with_"` results in setters like `with_x` or `with_y`. This option is combinable
@@ -267,20 +317,10 @@ use core::ops::FnOnce;
 pub use typed_builder_macro::TypedBuilder;
 
 #[doc(hidden)]
-pub trait Optional<T> {
-    fn into_value<F: FnOnce() -> T>(self, default: F) -> T;
-}
+pub trait NextFieldDefault<TypedBuilderExistingFields> {
+    type Output;
 
-impl<T> Optional<T> for () {
-    fn into_value<F: FnOnce() -> T>(self, default: F) -> T {
-        default()
-    }
-}
-
-impl<T> Optional<T> for (T,) {
-    fn into_value<F: FnOnce() -> T>(self, _: F) -> T {
-        self.0
-    }
+    fn resolve(input: TypedBuilderExistingFields) -> Self::Output;
 }
 
 // It'd be nice for the compilation tests to live in tests/ with the rest, but short of pulling in
