@@ -254,7 +254,7 @@ fn test_field_dependencies_in_build() {
         x: Option<i32>,
         #[builder(default = 10)]
         y: i32,
-        #[builder(default = vec![y, 30, 40])]
+        #[builder(default = vec![*y, 30, 40])]
         z: Vec<i32>,
     }
 
@@ -329,7 +329,7 @@ fn test_docs() {
         #[allow(dead_code)]
         x: i32,
         #[builder(
-                default = x,
+                default = *x,
                 setter(
                     doc = "Set `z`. If you don't specify a value it'll default to the value specified for `x`.",
                 ),
@@ -646,6 +646,7 @@ fn test_clone_builder() {
 #[test]
 #[allow(clippy::items_after_statements)]
 fn test_clone_builder_with_generics() {
+    #[allow(dead_code)]
     #[derive(PartialEq, Default)]
     struct Uncloneable;
 
@@ -742,7 +743,7 @@ fn test_unsized_generic_params() {
 }
 
 #[test]
-fn test_field_setter_transform() {
+fn test_field_setter_transform_closure() {
     #[derive(PartialEq)]
     struct Point {
         x: i32,
@@ -763,6 +764,72 @@ fn test_field_setter_transform() {
     );
 }
 
+#[test]
+fn test_field_setter_transform_fn() {
+    struct MBaseCase;
+
+    struct MClosure;
+
+    // Lifetime is not needed, just added to test.
+    trait IntoValue<'a, T, M> {
+        fn into_value(self) -> T;
+    }
+
+    impl<T, I> IntoValue<'_, T, MBaseCase> for I
+    where
+        I: Into<T>,
+    {
+        fn into_value(self) -> T {
+            self.into()
+        }
+    }
+
+    impl<T, F> IntoValue<'_, T, MClosure> for F
+    where
+        F: FnOnce() -> T,
+    {
+        fn into_value(self) -> T {
+            self()
+        }
+    }
+
+    #[derive(TypedBuilder)]
+    struct Foo {
+        #[builder(
+            setter(
+                fn transform<'a, M>(value: impl IntoValue<'a, String, M>)
+                where
+                    M: 'a,
+                 {
+                    value.into_value()
+                },
+            )
+        )]
+        s: String,
+    }
+
+    // Check where clause and return type
+    #[derive(TypedBuilder)]
+    struct Bar {
+        #[builder(
+            setter(
+                fn transform<A>(value: A) -> String
+                where
+                    A: std::fmt::Display,
+                 {
+                    value.to_string()
+                },
+            )
+        )]
+        s: String,
+    }
+
+    assert_eq!(Foo::builder().s("foo").build().s, "foo".to_owned());
+    assert_eq!(Foo::builder().s(|| "foo".to_owned()).build().s, "foo".to_owned());
+
+    assert_eq!(Bar::builder().s(42).build().s, "42".to_owned());
+}
+
 #[test]
 fn test_build_method() {
     #[derive(PartialEq, TypedBuilder)]
@@ -1096,3 +1163,55 @@ fn test_mutators_with_type_param() {
 
     assert_eq!(Foo::builder().x_plus::<HasSImpl>(1).build(), Foo { x: 1 });
 }
+
+#[test]
+fn test_default_with_generic_bounds() {
+    #[derive(Debug, PartialEq, TypedBuilder)]
+    struct Foo<T> {
+        #[builder(default, default_where(T: Default))]
+        x: T,
+    }
+
+    #[derive(Debug, PartialEq)]
+    struct HasNoDefault {
+        y: i32,
+    }
+
+    assert_eq!(Foo::builder().build(), Foo { x: 0 });
+
+    assert_eq!(
+        Foo::builder().x(HasNoDefault { y: 7 }).build(),
+        Foo {
+            x: HasNoDefault { y: 7 }
+        }
+    );
+}
+
+#[test]
+fn test_custom_default_with_generic_bounds() {
+    use core::fmt::Debug;
+    use core::str::FromStr;
+
+    #[derive(Debug, PartialEq, TypedBuilder)]
+    struct Foo<T> {
+        x: &'static str,
+        #[builder(default = x.parse().unwrap(), default_where(T: FromStr, <T as FromStr>::Err : Debug))]
+        y: T,
+    }
+
+    assert_eq!(Foo::builder().x("42").build(), Foo { x: "42", y: 42 });
+}
+
+#[test]
+fn test_builder_type_with_derive_attribute() {
+    #[derive(TypedBuilder)]
+    #[builder(builder_type(attributes(#[derive(PartialEq, Debug)])))]
+    #[allow(dead_code)]
+    struct Foo {
+        x: i32,
+        y: i32,
+    }
+
+    assert_eq!(Foo::builder().x(1), Foo::builder().x(1));
+    assert_ne!(Foo::builder().x(1), Foo::builder().x(2));
+}
